#
# spec file for package when-command
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define _version 0.9.12-beta.5
Name:           when-command
Version:        0.9.12~beta5
Release:        lp152.3.2
Summary:        Configurable user task scheduler
License:        BSD-3-Clause
Group:          Productivity/Other
Url:            http://almostearthling.github.io/when-command
Source:         https://github.com/almostearthling/%{name}/archive/v%{_version}.tar.gz#/%{name}-%{_version}.tar.gz
Source1:        %{name}.appdata.xml
Source2:        %{name}-rpmlintrc
BuildRequires:  fdupes
BuildRequires:  gobject-introspection-devel
BuildRequires:  hicolor-icon-theme
BuildRequires:  libXss1
BuildRequires:  python3-devel
BuildRequires:  python3-gobject
BuildRequires:  python3-pyinotify
BuildRequires:  python3-setuptools
BuildRequires:  update-desktop-files
Requires:       libXss1
Requires:       python3-gobject
Requires:       python3-pyinotify
Recommends:     %{name}-lang
BuildArch:      noarch
%if 0%{?suse_version} > 1320 || 0%{?sle_version} >= 120200
Requires:       python3-gobject-Gdk
%endif

%description
When is a configurable user task scheduler. It interacts with the
user through a GUI, where the user can define tasks and conditions,
as well as relationships of causality that bind conditions to
tasks. When a condition is bound to a task, it is said to trigger a
task.

%lang_package

%prep
%setup -q -n %{name}-%{_version}
cp -f %{SOURCE1} %{name}.appdata.xml
sed -i 's/^\(Exec=\).*$/\1%{name}/' share/applications/%{name}.desktop

%build
python3 setup.py build

%install
python3 setup.py install \
  --root=%{buildroot} --prefix=%{_prefix}

install -Dpm 0644 %{name}.appdata.xml \
  %{buildroot}%{_datadir}/appdata/%{name}.appdata.xml

mkdir -p %{buildroot}%{_docdir}/
mv -f %{buildroot}%{_datadir}/doc/%{name}/ \
  %{buildroot}%{_docdir}/%{name}/

%suse_update_desktop_file -r -G "When scheduler" %{name} Utility TimeUtility

%fdupes %{buildroot}%{_prefix}/
%find_lang %{name}

%post
%desktop_database_post
%icon_theme_cache_post

%postun
%desktop_database_postun
%icon_theme_cache_postun

%files
%defattr(-,root,root)
%doc %{_docdir}/%{name}/
%{_bindir}/%{name}
%{_datadir}/%{name}/
%{_datadir}/applications/%{name}.desktop
%dir %{_datadir}/appdata/
%{_datadir}/appdata/%{name}.appdata.xml
%{_datadir}/icons/hicolor/*/apps/%{name}.*
%{_mandir}/man?/%{name}.?%{?ext_man}
%{python3_sitelib}/when_command-*

%files lang -f %{name}.lang
%defattr(-,root,root)

%changelog
* Tue May  9 2017 sor.alexei@meowr.ru
- Update to version 0.9.12~beta5 (changes since 0.9.12~beta3):
  * When an interval based condition was created and hours were
    chosen as time unit, the applet ignored this choice and still
    used minutes (gh#almostearthling/when-command#91).
  * Introduce some more thorough checks when registering stock and
    user events, so that unsupported D-Bus signals result in
    disabled events when all possible implementations have been
    tried for. This resulted in a more portable way to handle
    battery related events, that weren't actually functioning on
    Ubuntu 16.04 due to changes in the D-Bus implementation
    (gh#almostearthling/when-command#92).
* Sat Jul 23 2016 sor.alexei@meowr.ru
- Update to version 0.9.12~beta3:
  * Add a possibility to reset the success status of condition
    tests so that also tests that have been successful during one
    very long session can be performed again at user's request.
  * Workaround a potential error when a locale is not supported.
- Add a missing python3-gobject-Gdk dependency.
* Mon May 16 2016 jengelh@inai.de
- Add rpmlintrc control file
* Sat May  7 2016 sor.alexei@meowr.ru
- Update to version 0.9.11~beta1 (changes since 0.9.10~beta2):
  * Fix a bug that would run activities scheduled for time
    specifications containing zeros immediately after their creation.
  * Fix a bug that prevented the disabled state of a condition to
    be retained when set through the Remote API.
  * Support the new interface to external devices featured in
    gvfs 1.26, lack of it prevented When to correctly register
    events related to connection of external storage devices.
- Alter official when-command.desktop instead of supplying an other
  one.
- Add a basic when-command.appdata.xml file.
* Fri Mar  4 2016 sor.alexei@meowr.ru
- Update to 0.9.10~beta2 (changes since 0.9.9~beta2):
  * Add possibility to pause selected condition checks through the
    remote API.
  * Fix a bug that prevented perstistence of suspension state if it
    had been set using the Remote D-Bus API.
* Thu Feb 11 2016 sor.alexei@meowr.ru
- Update to 0.9.9~beta2 (changes since 0.9.4~beta2):
  * Register all stock events from Linux Mint 17.x with
    Cinnamon desktop environment and Elementary OS Freya.
  * Inspect the idle time by directly querying the X server instead
    of relying on xprintidle.
  * Immediately apply most of the settings as soon as the
    Settings box is accepted.
  * Expose more conventionally named methods on the D-Bus.
  * A full-featured D-Bus interface.
  * Fix a bug that prevented dialog boxes to be shown if When was
    restarted in Minimalistic Mode and was reset to normal mode
    through the Settings dialog box.
  * The D-Bus Remote API is now rather stable and usable, through
    bug fixes and introduction of more thorough checks.
  * As a side effect, the import/export functions are more robust,
    as well as the ability to correctly create items from
    Item Definition Files.
  * Some glitches in the UI and other minor and possibly
    not-so-minor issues have been corrected.
- Add some missing dependencies.
* Tue Dec 29 2015 sor.alexei@meowr.ru
- Update to 0.9.4~beta2 (changes since 0.9.2~beta1):
  * Add battery related events for event-based conditions.
    Supported events are: charging, discharging, low battery.
  * Package has been stripped most of the documentation, since the
    documentation is much more accessible online than in the
    installation location.
  * A system-wide applet shortcut when using the LSB packaged
    version.
  * Item CLI Management (tasks, conditions and signal handlers can
    be added, listed and deleted using the CLI and item definition
    files).
  * Minimalistic Mode: the menu entries that show dialog boxes and
    their respective CLI counterparts can be hidden and disabled,
    de facto freezing the configuration and reducing memory
    footprint.
* Mon Nov 23 2015 sor.alexei@meowr.ru
- Initial package.
